@@ -1,6 +1,6 @@
 /*
  *
- * Copyright (C) 2019-2021 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -64,6 +64,10 @@ namespace ze_lib
     __zedlllocal context_t::context_t()
     {
         debugTraceEnabled = getenv_tobool( "ZE_ENABLE_LOADER_DEBUG_TRACE" );
+        memset(&initialzeDdiTable, 0, sizeof(ze_dditable_t));
+        memset(&initialzetDdiTable, 0, sizeof(zet_dditable_t));
+        memset(&initialzesDdiTable, 0, sizeof(zes_dditable_t));
+        memset(&initialzerDdiTable, 0, sizeof(zer_dditable_t));
     };
 
     ///////////////////////////////////////////////////////////////////////////////
@@ -140,7 +144,6 @@ namespace ze_lib
             return result;
         }
 
-        bool zeInitDriversSupport = true;
         ze_api_version_t current_api_version = version;
         const std::string loader_name = "loader";
         for (auto &component : versions) {
@@ -152,7 +155,6 @@ namespace ze_lib
                     if (component.component_lib_version.minor < 18) {
                         std::string message = "ze_lib Context Init() Version Does not support zeInitDrivers";
                         debug_trace_message(message, "");
-                        zeInitDriversSupport = false;
                     }
                 } else {
                     std::string message = "ze_lib Context Init() Loader version is too new, returning ";
@@ -177,14 +179,21 @@ namespace ze_lib
             return ZE_RESULT_ERROR_UNINITIALIZED;
         }
         tracing_lib = getTracing();
-        typedef ze_result_t (ZE_APICALL *zelLoaderTracingLayerInit_t)(std::atomic<ze_dditable_t *> &zeDdiTable);
-        auto loaderTracingLayerInit = reinterpret_cast<zelLoaderTracingLayerInit_t>(
+        typedef ze_result_t (ZE_APICALL *zelLoaderZeTracingLayerInit_t)(std::atomic<ze_dditable_t *> &zeDdiTable);
+        auto loaderZeTracingLayerInit = reinterpret_cast<zelLoaderZeTracingLayerInit_t>(
                 GET_FUNCTION_PTR(loader, "zelLoaderTracingLayerInit") );
-        if (loaderTracingLayerInit == nullptr) {
+        if (loaderZeTracingLayerInit == nullptr) {
             std::string message = "ze_lib Context Init() zelLoaderTracingLayerInit missing, disabling dynamic tracer support ";
             debug_trace_message(message, "");
             this->dynamicTracingSupported = false;
         }
+        typedef ze_result_t (ZE_APICALL *zelLoaderZerTracingLayerInit_t)(std::atomic<zer_dditable_t *> &zerDdiTable);
+        auto loaderZerTracingLayerInit = reinterpret_cast<zelLoaderZerTracingLayerInit_t>(
+                GET_FUNCTION_PTR(loader, "zelLoaderZerTracingLayerInit") );
+        if (loaderZerTracingLayerInit == nullptr) {
+            std::string message = "ze_lib Context Init() zelLoaderZerTracingLayerInit missing, dynamic tracing support for Zer API's will be unavailable ";
+            debug_trace_message(message, "");
+        }
         typedef loader::context_t * (ZE_APICALL *zelLoaderGetContext_t)();
         auto loaderGetContext = reinterpret_cast<zelLoaderGetContext_t>(
                 GET_FUNCTION_PTR(loader, "zelLoaderGetContext") );
@@ -209,6 +218,7 @@ namespace ze_lib
             ze_lib::context->zeDdiTable.exchange(&ze_lib::context->initialzeDdiTable);
             ze_lib::context->zetDdiTable.exchange(&ze_lib::context->initialzetDdiTable);
             ze_lib::context->zesDdiTable.exchange(&ze_lib::context->initialzesDdiTable);
+            ze_lib::context->zerDdiTable.exchange(&ze_lib::context->initialzerDdiTable);
         }
 
         // Given zesInit, then zesDrivers needs to be used as the sysmanInstanceDrivers;
@@ -252,6 +262,16 @@ namespace ze_lib
                 debug_trace_message(message, to_string(result));
             }
         }
+        // Init the ZER DDI Tables
+        if (ZE_RESULT_SUCCESS == result)
+        {
+            result = zerDdiTableInit(version);
+            if (result != ZE_RESULT_SUCCESS)
+            {
+                std::string message = "ze_lib Context Init() zerDdiTableInit failed with ";
+                debug_trace_message(message, to_string(result));
+            }
+        }
         // Init the Tracing API DDI Tables
         if( ZE_RESULT_SUCCESS == result )
         {
@@ -265,80 +285,21 @@ namespace ze_lib
         if( ZE_RESULT_SUCCESS == result )
         {
             #ifdef L0_STATIC_LOADER_BUILD
-            if (loaderTracingLayerInit) {
-                result = loaderTracingLayerInit(this->pTracingZeDdiTable);
+            if (loaderZeTracingLayerInit) {
+                result = loaderZeTracingLayerInit(this->pTracingZeDdiTable);
+                if (result == ZE_RESULT_SUCCESS && loaderZerTracingLayerInit) {
+                    result = loaderZerTracingLayerInit(this->pTracingZerDdiTable);
+                }
             }
             #else
             result = zelLoaderTracingLayerInit(this->pTracingZeDdiTable);
+            if (result == ZE_RESULT_SUCCESS) {
+                result = zelLoaderZerTracingLayerInit(this->pTracingZerDdiTable);
+            }
             #endif
         }
         // End DDI Table Inits
 
-        // Check which drivers and layers can be init on this system.
-        if( ZE_RESULT_SUCCESS == result)
-        {
-            // Check which drivers support the ze_driver_flag_t specified
-            // No need to check if only initializing sysman
-            bool requireDdiReinit = false;
-            #ifdef L0_STATIC_LOADER_BUILD
-            if (zeInitDriversSupport) {
-                typedef ze_result_t (ZE_APICALL *zelLoaderDriverCheck_t)(ze_init_flags_t flags, ze_init_driver_type_desc_t* desc, ze_global_dditable_t *globalInitStored, zes_global_dditable_t *sysmanGlobalInitStored, bool *requireDdiReinit, bool sysmanOnly);
-                auto loaderDriverCheck = reinterpret_cast<zelLoaderDriverCheck_t>(
-                        GET_FUNCTION_PTR(loader, "zelLoaderDriverCheck") );
-                if (loaderDriverCheck == nullptr) {
-                    std::string message = "ze_lib Context Init() zelLoaderDriverCheck missing, returning ";
-                    debug_trace_message(message, to_string(ZE_RESULT_ERROR_UNINITIALIZED));
-                    return ZE_RESULT_ERROR_UNINITIALIZED;
-                }
-                result = loaderDriverCheck(flags, desc, &ze_lib::context->initialzeDdiTable.Global, &ze_lib::context->initialzesDdiTable.Global, &requireDdiReinit, sysmanOnly);
-            } else {
-                typedef ze_result_t (ZE_APICALL *zelLoaderDriverCheck_t)(ze_init_flags_t flags, ze_global_dditable_t *globalInitStored, zes_global_dditable_t *sysmanGlobalInitStored, bool *requireDdiReinit, bool sysmanOnly);
-                auto loaderDriverCheck = reinterpret_cast<zelLoaderDriverCheck_t>(
-                        GET_FUNCTION_PTR(loader, "zelLoaderDriverCheck") );
-                if (loaderDriverCheck == nullptr) {
-                    std::string message = "ze_lib Context Init() zelLoaderDriverCheck missing, returning ";
-                    debug_trace_message(message, to_string(ZE_RESULT_ERROR_UNINITIALIZED));
-                    return ZE_RESULT_ERROR_UNINITIALIZED;
-                }
-                result = loaderDriverCheck(flags, &ze_lib::context->initialzeDdiTable.Global, &ze_lib::context->initialzesDdiTable.Global, &requireDdiReinit, sysmanOnly);
-            }
-            #else
-            result = zelLoaderDriverCheck(flags, desc, &ze_lib::context->initialzeDdiTable.Global, &ze_lib::context->initialzesDdiTable.Global, &requireDdiReinit, sysmanOnly);
-            #endif
-            if (result != ZE_RESULT_SUCCESS) {
-                std::string message = "ze_lib Context Init() zelLoaderDriverCheck failed with ";
-                debug_trace_message(message, to_string(result));
-            }
-            // If a driver was removed from the driver list, then the ddi tables need to be reinit to allow for passthru directly to the driver.
-            if (requireDdiReinit && loaderContextAccessAllowed) {
-                // If a user has already called the core apis, then ddi table reinit is not possible due to handles already being read by the user.
-                if (!sysmanOnly && !ze_lib::context->zeInuse) {
-                    // reInit the ZE DDI Tables
-                    if( ZE_RESULT_SUCCESS == result )
-                    {
-                        result = zeDdiTableInit(version);
-                    }
-                    // reInit the ZET DDI Tables
-                    if( ZE_RESULT_SUCCESS == result )
-                    {
-                        result = zetDdiTableInit(version);
-                    }
-                    // If ze/zet ddi tables have been reinit and no longer use the intercept layer, then handles passed to zelLoaderTranslateHandleInternal do not require translation.
-                    // Setting intercept_enabled==false changes the behavior of zelLoaderTranslateHandleInternal to avoid translation.
-                    // Translation is only required if the intercept layer is enabled for the ZE handle types.
-                    loaderContext->intercept_enabled = false;
-                }
-                // If a user has already called the zes/ze apis, then ddi table reinit is not possible due to handles already being read by the user.
-                if (!(ze_lib::context->zesInuse || ze_lib::context->zeInuse)) {
-                    // reInit the ZES DDI Tables
-                    if( ZE_RESULT_SUCCESS == result )
-                    {
-                        result = zesDdiTableInit(version);
-                    }
-                }
-            }
-        }
-
         if( ZE_RESULT_SUCCESS == result )
         {
 #ifdef L0_STATIC_LOADER_BUILD
@@ -428,6 +389,54 @@ zelLoaderGetVersions(
 #endif
 }
 
+ze_result_t ZE_APICALL
+zelGetLoaderVersion(
+   zel_component_version_t *version)     //Pointer to version structure to be filled with loader version information
+{
+#ifdef L0_STATIC_LOADER_BUILD
+    // zelLoaderGetVersion doesn't require initialization, so we can load the library temporarily if needed
+    HMODULE loaderHandle = nullptr;
+    bool temporaryLoad = false;
+
+    if(ze_lib::context && ze_lib::context->loader) {
+        // Use existing loader
+        loaderHandle = ze_lib::context->loader;
+    } else {
+        // Temporarily load the loader library to get version info
+        std::string loaderLibraryPath;
+        auto loaderLibraryPathEnv = getenv_string("ZEL_LIBRARY_PATH");
+        if (!loaderLibraryPathEnv.empty()) {
+            loaderLibraryPath = loaderLibraryPathEnv;
+        }
+#ifdef _WIN32
+        else {
+            loaderLibraryPath = readLevelZeroLoaderLibraryPath();
+        }
+#endif
+        std::string loaderFullLibraryPath = create_library_path(MAKE_LIBRARY_NAME( "ze_loader", L0_LOADER_VERSION), loaderLibraryPath.c_str());
+        loaderHandle = LOAD_DRIVER_LIBRARY(loaderFullLibraryPath.c_str());
+        if (nullptr == loaderHandle) {
+            return ZE_RESULT_ERROR_UNINITIALIZED;
+        }
+        temporaryLoad = true;
+    }
+
+    typedef ze_result_t (ZE_APICALL *zelLoaderGetVersion_t)(zel_component_version_t *version);
+    auto getVersion = reinterpret_cast<zelLoaderGetVersion_t>(
+            GET_FUNCTION_PTR(loaderHandle, "zelLoaderGetVersion") );
+    ze_result_t result = getVersion(version);
+
+    // Clean up temporary load
+    if (temporaryLoad && loaderHandle) {
+        FREE_DRIVER_LIBRARY(loaderHandle);
+    }
+
+    return result;
+#else
+    return zelLoaderGetVersion(version);
+#endif
+}
+
 
 ze_result_t ZE_APICALL
 zelLoaderTranslateHandle(
@@ -618,6 +627,39 @@ zelEnableTracingLayer()
     }
     if (ze_lib::context->tracingLayerEnableCounter.fetch_add(1) == 0) {
         ze_lib::context->zeDdiTable.exchange(ze_lib::context->pTracingZeDdiTable);
+        if (ze_lib::context->pTracingZerDdiTable != nullptr) {
+            ze_lib::context->zerDdiTable.exchange(ze_lib::context->pTracingZerDdiTable);
+        }
+    }
+    #endif
+    return ZE_RESULT_SUCCESS;
+}
+
+ze_result_t ZE_APICALL
+zelGetTracingLayerState
+(
+    bool* enabled // Pointer to bool to receive tracing layer state
+)
+{
+    if (enabled == nullptr) {
+        return ZE_RESULT_ERROR_INVALID_NULL_POINTER;
+    }
+    #ifdef L0_STATIC_LOADER_BUILD
+    if(nullptr == ze_lib::context->loader)
+        return ZE_RESULT_ERROR_UNINITIALIZED;
+    typedef ze_result_t (ZE_APICALL *zelGetTracingLayerStateInternal_t)(bool* enabled);
+    auto getDynamicTracingState = reinterpret_cast<zelGetTracingLayerStateInternal_t>(
+            GET_FUNCTION_PTR(ze_lib::context->loader, "zelGetTracingLayerState") );
+    return getDynamicTracingState(enabled);
+    #else
+    if (ze_lib::context->dynamicTracingSupported == false) {
+        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+    }
+    if (loader::context) {
+        *enabled = loader::context->tracingLayerEnabled;
+    }
+    if (!*enabled) {
+        *enabled = (ze_lib::context->tracingLayerEnableCounter.load() > 0);
     }
     #endif
     return ZE_RESULT_SUCCESS;
@@ -639,6 +681,9 @@ zelDisableTracingLayer()
     }
     if (ze_lib::context->tracingLayerEnableCounter.fetch_sub(1) <= 1) {
         ze_lib::context->zeDdiTable.exchange(&ze_lib::context->initialzeDdiTable);
+        if (ze_lib::context->pTracingZerDdiTable != nullptr) {
+            ze_lib::context->zerDdiTable.exchange(&ze_lib::context->initialzerDdiTable);
+        }
     }
     #endif
     return ZE_RESULT_SUCCESS;
